import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  arc,
  pie,
  scaleBand,
  scaleLinear,
  max,
  format
} from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';
import { PlotMenu } from './PlotMenu';

const width = window.innerWidth;
const height = window.innerHeight;
const margin = {
  top: 20,
  right: 30,
  bottom: 65,
  left: 220,
};
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const xAxisLabelOffset = 50;

const App = () => {
  const data = useData();
  
 // const initialPlotAttribute = 'Total';
  const initialXAttribute = 'Total';
  //const [plotAttribute, setPlotAttribute] = useState(initialPlotAttribute);
  const [xAttribute, setPlotAttribute] = useState(initialXAttribute);
  const xValue = d => d[xAttribute];
  
  console.log(xValue)

  if (!data) {
    return <pre>Loading...</pre>;
  }
  console.log(data[0]);

  //const xValue = plotVariable;
  const yValue = (d) => d.donorType;
  
  const siFormat = format('.2s');
  const xAxisTickFormat = n => siFormat(n).replace('G', 'B')

  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);

  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .padding(0.15);

  return (
    <svg width={width} height={height}>
      <g
        className="tick"
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        <AxisBottom
          tickFormat={xAxisTickFormat}
          xScale={xScale}
          innerHeight={innerHeight}
        />
        <AxisLeft yScale={yScale} />
        {/*<text 
          className="axis-label"
          x={innerWidth / 2} 
          textAnchor="middle"
        	y={innerHeight + xAxisLabelOffset}  
        >
          Population
        </text>*/}
        <Marks
          data={data}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          tooltipFormat={xAxisTickFormat}
        />
      </g>
      <g textAnchor="middle" transform={`translate(${width / 2}, ${height - 20})`}>
      	<PlotMenu updatePlotValue={setPlotAttribute} />
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
